@@ -423,12 +423,17 @@ def cli_qa_update(obj, qa_hash, microservices):
 
 @qa.command("delete", help="Delete QA env")
 @click.argument("qa_hashes", nargs=-1, required=True)
+@click.option("--force", is_flag=True, default=False, help="Force QA deletion")
 @click.pass_obj
-def cli_qa_delete(obj, qa_hashes):
+def cli_qa_delete(obj, qa_hashes, force):
     from suite_py.commands.qa import QA
 
     QA(
-        "delete", obj["project"], obj["config"], obj["tokens"], {"hashes": qa_hashes}
+        "delete",
+        obj["project"],
+        obj["config"],
+        obj["tokens"],
+        {"hashes": qa_hashes, "force": force},
     ).run()
 
 
